==> gpredict_0.4.0.orig.tar.gz: gpredict-0.4.0/src/satprint.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
  satprint.h: Printing functions.

  Copyright (C)  2001-2003  Ran Hadary & Alexandru Csete.

  Authors:   Rand Hadary <hadary@users.sourceforge.net>
             Alexandru Csete <csete@users.sourceforge.net>

  Comments, questions and bugreports should be submitted via
  http://sourceforge.net/projects/groundstation/
  More details can be found at http://groundstation.sourceforge.net/
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the
          Free Software Foundation, Inc.,
	  59 Temple Place, Suite 330,
	  Boston, MA  02111-1307
	  USA
*/

#ifndef SATPRINT_H
#define SATPRINT_H

/* Pixel Size                    */
#define G_P_PIXELS 256
/* Number of data lines on page  */
#define PG_DATA_LINES 52

/* main API functions            */
void sat_print_current (void);
void sat_print_sat_aos (sat_t *sat, gchar **aoslist, guint size);
void sat_print_aos_det (sat_t *sat, gchar **aosdet, guint size);

#endif

==> gpredict_0.5.1.orig.tar.gz: gpredict-0.5.1/src/satprint.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
  satprint.h: Printing functions.

  Copyright (C)  2001-2005  Ran Hadary & Alexandru Csete.

  Authors:   Rand Hadary <hadary@users.sourceforge.net>
             Alexandru Csete <csete@users.sourceforge.net>

  Comments, questions and bugreports should be submitted via
  http://sourceforge.net/projects/groundstation/
  More details can be found at http://groundstation.sourceforge.net/
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the
          Free Software Foundation, Inc.,
	  59 Temple Place, Suite 330,
	  Boston, MA  02111-1307
	  USA
*/

#ifndef SATPRINT_H
#define SATPRINT_H

/* Pixel Size */
#define G_P_PIXELS 256

/* Number of data lines on page  */
#define PG_DATA_LINES 52

/* main API functions            */
void sat_print_current (void);
void sat_print_sat_aos (sat_t *sat, gchar **aoslist, guint size);
void sat_print_aos_det (sat_t *sat, gchar **aosdet, guint size, guint orbit);

#endif
